@@ -122,6 +122,8 @@ class LambdaEventSourceMapping(Resource):
         "AmazonManagedKafkaEventSourceConfig": GeneratedProperty(),
         "SelfManagedKafkaEventSourceConfig": GeneratedProperty(),
         "ScalingConfig": GeneratedProperty(),
+        "ProvisionedPollerConfig": GeneratedProperty(),
+        "MetricsConfig": GeneratedProperty(),
     }
 
     runtime_attrs = {"name": lambda self: ref(self.logical_id)}
